@@ -1,6 +1,6 @@
 /*
  *  ydpdict
- *  (C) Copyright 1998-2011 Wojtek Kaniewski <wojtekka@toxygen.net>
+ *  (C) Copyright 1998-2023 Wojtek Kaniewski <wojtekka@toxygen.net>
  *                          Piotr Domagalski <szalik@szalik.net>
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -47,16 +47,13 @@
 
 #ifdef ENABLE_NLS
 #include <libintl.h>
+#include <locale.h>
 #define _(x) gettext(x)
 #else
 #define _(x) x
 #endif
 #define N_(x) x
 
-#ifdef HAVE_LOCALE_H
-#include <locale.h>
-#endif
-
 #ifdef HAVE_LIBAO
 #include <ao/ao.h>
 #endif
@@ -102,7 +99,6 @@ int resized_term;	///< Terminal resize flag
 
 WINDOW *window_word;	///< Wordlist window
 WINDOW *window_def;	///< Definition window
-WINDOW *window_header;	///< Header window
 WINDOW *window_sep;	///< Separator window
 WINDOW *window_arrows;	///< Arrows window
 
@@ -189,7 +185,8 @@ const char *qualifiers_format = "{\\line{\\cf2 %s} {%s}}";
 
 const char *help[] =
 {
-	N_("{\\b Help}{\\pard\\pard}"),
+	"{\\b " HEADER_NAME "}",
+	"{\\line{\\b " HEADER_COPYRIGHT "}}{\\pard\\pard}",
 	N_("{\\cf2 F1} or {\\cf2 ?} - this help"),
 	N_("{\\line{\\cf2 Tab} - change focus}"),
 	N_("{\\line{\\cf2 Up} and {\\cf2 Down} - scroll up and down}"),
@@ -220,9 +217,6 @@ void show_error(const char *msg)
 	if (window_word)
 		delwin(window_word);
 
-	if (window_header)
-		delwin(window_header);
-
 	if (window_sep)
 		delwin(window_sep);
 
@@ -267,7 +261,6 @@ static void sigterm(int sig)
  */
 void update_all(void)
 {
-	wnoutrefresh(window_header);
 	wnoutrefresh(window_sep);
 	wnoutrefresh(window_def);
 	wnoutrefresh(window_arrows);
@@ -289,21 +282,18 @@ void create_windows(void)
 		delwin(window_word);
 	if (window_def)
 		delwin(window_def);
-	if (window_header)
-		delwin(window_header);
 	if (window_sep)
 		delwin(window_sep);
 	if (window_arrows)
 		delwin(window_arrows);
 	
 	/* Create windows */
-	window_word = newwin(screen_height - 3, 20, 2, 2);
-	window_def = newwin(screen_height - 3, screen_width - 29, 2, 27);
-	window_header = newwin(1, screen_width, 0, 0);
-	window_sep = newwin(screen_height - 1, 4, 1, 23);
-	window_arrows = newwin(screen_height - 1, 1, 1, screen_width - 1);
+	window_word = newwin(screen_height - 2, 20, 1, 2);
+	window_def = newwin(screen_height - 2, screen_width - 29, 1, 27);
+	window_sep = newwin(screen_height, 4, 0, 23);
+	window_arrows = newwin(screen_height, 1, 0, screen_width - 1);
 
-	if (!window_word || !window_def || !window_header || !window_sep)
+	if (!window_word || !window_def || !window_sep)
 		show_error(_("Out of memory"));
 	
 	/* Configure windows */
@@ -314,17 +304,6 @@ void create_windows(void)
 	/* Draw vertical bar */
 	for (i = 0; i < screen_height; i++)
 		mvwaddch(window_sep, i, 1, ACS_VLINE);
-
-	/* Draw screen header */
-	wattrset(window_header, A_REVERSE);
-
-	for (i = 0; i < screen_width; i++)
-		waddch(window_header, ' ');
-
-	mvwaddstr(window_header, 0, 1, HEADER_NAME);
-
-	if (screen_width - strlen(HEADER_COPYRIGHT) - 1 > strlen(HEADER_NAME) + 2);
-		mvwaddstr(window_header, 0, screen_width - strlen(HEADER_COPYRIGHT) - 1, HEADER_COPYRIGHT);
 }
 
 /**
@@ -342,8 +321,8 @@ void check_size(void)
 {
 	int newx, newy, fake = 0, diff;
 
-	newx = stdscr->_maxx + 1;
-	newy = stdscr->_maxy + 1;
+	newx = getmaxx(stdscr);
+	newy = getmaxy(stdscr);
 
 	/* Minimum size */
 	if (newx < 29)
@@ -357,12 +336,12 @@ void check_size(void)
 	screen_width = newx;
 	screen_height = newy;
 
-	diff = list_page + (screen_height - 4) - word_count;
+	diff = list_page + (screen_height - 3) - word_count;
 	if (diff > 0) {
 		list_page -= diff;
 		list_index += diff;
 	}
-	diff = list_index - (screen_height - 5);
+	diff = list_index - (screen_height - 4);
 	if (diff > 0) {
 		list_page += diff;
 		list_index -= diff;
@@ -383,7 +362,7 @@ void resize(void)
 	resized_term = 0;
 }
 
-#define is_visible(x) ((ypos >= first && ypos < (screen_height - 3) + first) ? x : "")
+#define is_visible(x) ((ypos >= first && ypos < (screen_height - 2) + first) ? x : "")
 
 /**
  * \brief Prints the definition
@@ -398,7 +377,7 @@ int def_print(char *def, int first)
 	int attr = color_text, attrs[16], level = 0, lastsp = 1, xpos = 0;
 	int phon = 0, lp = 0, dispword, newline_, newattr, lastnl = 0;
 	int ypos = 0, margin = 0, tp, newphon;
-	char token[64], line[80];
+	char token[64], line[screen_width];
 
 	if (!def)
 		return 1;
@@ -527,7 +506,7 @@ int def_print(char *def, int first)
 		def++;
 
 		if (dispword && lp) {
-			if (50 - xpos < lp) {
+			if (screen_width - 30 - xpos < lp) {
 				waddstr(window_def, is_visible("\n"));
 				ypos++;
 				if (margin)
@@ -555,7 +534,7 @@ int def_print(char *def, int first)
 				}
 			}
 
-			if (lastsp && xpos != 50) {
+			if (lastsp && xpos != screen_width - 30) {
 				waddstr(window_def, is_visible(" "));
 				xpos++;
 			}
@@ -580,7 +559,7 @@ int def_print(char *def, int first)
 	}
 
 	if (lp) {
-		if (50 - xpos < lp) {
+		if (screen_width - 30 - xpos < lp) {
 			waddstr(window_def, is_visible("\n"));
 			ypos++;
 		}
@@ -634,8 +613,8 @@ void input_find(void)
 			list_page = idx;
 			list_index = 0;
 
-			if (list_page > word_count - (screen_height - 4)) {
-				list_page = word_count - (screen_height - 4);
+			if (list_page > word_count - (screen_height - 3)) {
+				list_page = word_count - (screen_height - 3);
 				list_index = idx - list_page;
 			}
 
@@ -656,7 +635,7 @@ void list_redraw(void)
 	werase(window_word);
 
 	if (dict) {
-		for (y = 0; y < (screen_height - 4); y++) {
+		for (y = 0; y < (screen_height - 3); y++) {
 			wattrset(window_word, (y == list_index) ? A_REVERSE : A_NORMAL);
 			mvwaddstr(window_word, y + 1, 0, "                    ");
 	
@@ -707,7 +686,7 @@ void def_redraw(void)
 
 	wattrset(window_arrows, A_DIM);
 	mvwaddch(window_arrows, 1, 0, (def_index > 0) ? ACS_UARROW : ' ');
-	mvwaddch(window_arrows, screen_height - 3, 0, (def_index < def_height - (screen_height - 3)) ? ACS_DARROW : ' ');
+	mvwaddch(window_arrows, screen_height - 2, 0, (def_index < def_height - (screen_height - 2)) ? ACS_DARROW : ' ');
 
 	update_all();
 }
@@ -798,9 +777,10 @@ int main(int argc, char **argv)
 	MEVENT m_event;
 	int bg;
 
-#ifdef HAVE_LOCALE_H
+#ifdef ENABLE_NLS
 	setlocale(LC_ALL, "");
-	textdomain("ydpdict");
+	bindtextdomain(PACKAGE, LOCALEDIR);
+	textdomain(PACKAGE);
 #endif
 
 #ifdef HAVE_LIBAO
@@ -873,8 +853,8 @@ int main(int argc, char **argv)
 		switch (ch) {
 
 #define __MOUSE_IN(window, event, correct1, correct2, correct3, correct4) (\
-	 event.y > (window->_begy + correct1) && event.y < (window->_begy + window->_maxy + correct2) &&\
-	 event.x > (window->_begx + correct3) && event.x < (window->_begx + window->_maxx + correct4))
+	 event.y > (getbegy(window) + correct1) && event.y < (getbegy(window) + getmaxy(window) - 1 + correct2) &&\
+	 event.x > (getbegx(window) + correct3) && event.x < (getbegx(window) + getmaxx(window) - 1 + correct4))
 
 			case KEY_MOUSE:
 				if (getmouse(&m_event) == OK) {
@@ -905,7 +885,7 @@ int main(int argc, char **argv)
 							mvwin_wch(window_def, m_event.y - 2, x, &cc);
 							ch = cc.chars[0];
 							buf[i++] = ch;
-						} while ((iswalpha(ch) || ch == L'-') && x < window_def->_maxx);
+						} while ((iswalpha(ch) || ch == L'-') && x < getmaxx(window_def) - 1);
 
 						buf[--i] = L'\0';
 
@@ -969,7 +949,7 @@ int main(int argc, char **argv)
 
 			case 10: /* Enter */
 				if (focus) {
-					if (def_index < def_height - (screen_height - 3))
+					if (def_index < def_height - (screen_height - 2))
 						def_index++;
 				} else {
 					wchar_t *c = input + wcslen(input) - 1;
@@ -1033,9 +1013,9 @@ int main(int argc, char **argv)
 				int i;
 
 				for (i = 0; i < sizeof(help) / sizeof(help[0]); i++)
-					len += strlen(gettext(help[i]));
+					len += strlen(_(help[i]));
 
-				len += strlen(gettext(help_footer));
+				len += strlen(_(help_footer));
 
 				xfree(def);
 
@@ -1043,9 +1023,9 @@ int main(int argc, char **argv)
 				def[0] = 0;
 
 				for (i = 0; i < sizeof(help) / sizeof(help[0]); i++)
-					strcat(def, gettext(help[i]));
+					strcat(def, _(help[i]));
 
-				sprintf(def + strlen(def), gettext(help_footer), HELP_EMAIL, HELP_WEBSITE);
+				sprintf(def + strlen(def), _(help_footer), HELP_EMAIL, HELP_WEBSITE);
 
 				def_saved_index = def_index;
 				def_index = 0;
@@ -1090,22 +1070,22 @@ int main(int argc, char **argv)
 				unsigned int len = 0;
 				int i;
 
-				len += strlen(gettext(qualifiers_header));
+				len += strlen(_(qualifiers_header));
 
 				for (i = 0; i < sizeof(qualifiers) / sizeof(qualifiers[0]); i++) {
 					len += strlen(qualifiers_format);
 					len += strlen(qualifiers[i][0]);
-					len += strlen(gettext(qualifiers[i][1]));
+					len += strlen(_(qualifiers[i][1]));
 				}
 
 				xfree(def);
 
 				def = xmalloc(len);
 
-				strcpy(def, gettext(qualifiers_header));
+				strcpy(def, _(qualifiers_header));
 
 				for (i = 0; i < sizeof(qualifiers) / sizeof(qualifiers[0]); i++)
-					sprintf(def + strlen(def), qualifiers_format, qualifiers[i][0], gettext(qualifiers[i][1]));
+					sprintf(def + strlen(def), qualifiers_format, qualifiers[i][0], _(qualifiers[i][1]));
 
 				def_saved_index = def_index;
 				def_index = 0;
@@ -1134,15 +1114,15 @@ int main(int argc, char **argv)
 
 			case KEY_PPAGE:
 				if (focus) {
-	  				if (def_index > screen_height - 4)
-						def_index -= screen_height - 3;
+					if (def_index > screen_height - 3)
+						def_index -= screen_height - 2;
 					else
 						def_index = 0;
 				} else {
 					if (list_index > 0)
 						list_index = 0;
-					else if (list_page > screen_height - 5)
-						list_page -= screen_height - 4;
+					else if (list_page > screen_height - 4)
+						list_page -= screen_height - 3;
 					else
 						list_page = 0;
 
@@ -1153,12 +1133,12 @@ int main(int argc, char **argv)
 
 			case KEY_DOWN:
 				if (focus) {
-					if (def_index < def_height - (screen_height - 3))
+					if (def_index < def_height - (screen_height - 2))
 						def_index++;
 				} else {
-					if (list_index < screen_height - 5 && (list_index + 1 < word_count))
+					if (list_index < screen_height - 4 && (list_index + 1 < word_count))
 						list_index++;
-					else if (list_page < word_count - (screen_height - 4))
+					else if (list_page < word_count - (screen_height - 3))
 						list_page++;
 					def_index = 0;
 					def_update = 1;
@@ -1167,17 +1147,17 @@ int main(int argc, char **argv)
 
 			case KEY_NPAGE:
 				if (focus) {
-					if (def_index < def_height - (screen_height - 3) * 2 - 1)
-						def_index += screen_height - 3;
+					if (def_index < def_height - (screen_height - 2) * 2 - 1)
+						def_index += screen_height - 2;
 					else
-						def_index = def_height - (screen_height - 3);
+						def_index = def_height - (screen_height - 2);
 				} else {
-					if (list_index < screen_height - 5)
-						list_index = screen_height - 5;
-					else if (list_page < word_count - (screen_height - 4) * 2 - 1)
-						list_page += screen_height - 4;
+					if (list_index < screen_height - 4)
+						list_index = screen_height - 4;
+					else if (list_page < word_count - (screen_height - 3) * 2 - 1)
+						list_page += screen_height - 3;
 					else
-						list_page = word_count - (screen_height - 4);
+						list_page = word_count - (screen_height - 3);
 					def_index = 0;
 					def_update = 1;
 				}
